@@ -2,11 +2,10 @@ import shutil
 
 from pathlib import Path
 from packaging.version import Version
-import subprocess
 
 from ansible_runner import defaults
+from ansible_runner.utils.importlib_compat import importlib_metadata
 
-import pkg_resources
 import pytest
 
 
@@ -35,9 +34,9 @@ def is_pre_ansible211():
     """
 
     try:
-        if pkg_resources.get_distribution('ansible-core').version:
+        if importlib_metadata.version("ansible-core"):
             return False
-    except pkg_resources.DistributionNotFound:
+    except importlib_metadata.PackageNotFoundError:
         # Must be ansible-base or ansible
         return True
 
@@ -51,18 +50,10 @@ def skipif_pre_ansible211(is_pre_ansible211):
 @pytest.fixture(scope="session")
 def is_pre_ansible212():
     try:
-        base_version = (
-            subprocess.run(
-                "python -c 'import ansible; print(ansible.__version__)'",
-                capture_output=True,
-                shell=True,
-            )
-            .stdout.strip()
-            .decode()
-        )
+        base_version = importlib_metadata.version("ansible")
         if Version(base_version) < Version("2.12"):
             return True
-    except pkg_resources.DistributionNotFound:
+    except importlib_metadata.PackageNotFoundError:
         pass
 
 
