@@ -4,8 +4,8 @@ from functools import partial
 from io import StringIO
 import os
 import re
-
 import six
+
 from pexpect import TIMEOUT, EOF
 
 import pytest
@@ -14,6 +14,7 @@ from ansible_runner.config.runner import RunnerConfig, ExecutionMode
 from ansible_runner.interface import init_runner
 from ansible_runner.loader import ArtifactLoader
 from ansible_runner.exceptions import ConfigurationError
+from test.utils.common import RSAKey
 
 try:
     Pattern = re._pattern_type
@@ -184,13 +185,14 @@ def test_prepare_env_sshkey(mocker):
     mocker.patch('os.makedirs', return_value=True)
     rc = RunnerConfig('/')
 
-    value = '01234567890'
-    sshkey_side_effect = partial(load_file_side_effect, 'env/ssh_key', value)
+    rsa_key = RSAKey()
+    rsa_private_key_value = rsa_key.private
+    sshkey_side_effect = partial(load_file_side_effect, 'env/ssh_key', rsa_private_key_value)
 
     mocker.patch.object(rc.loader, 'load_file', side_effect=sshkey_side_effect)
 
     rc.prepare_env()
-    assert rc.ssh_key_data == value
+    assert rc.ssh_key_data == rsa_private_key_value
 
 
 def test_prepare_env_defaults(mocker):
@@ -217,6 +219,37 @@ def test_prepare_env_directory_isolation(mocker):
     assert rc.cwd == '/tmp/foo'
 
 
+def test_prepare_env_directory_isolation_from_settings(mocker, project_fixtures):
+    '''
+    Test that sandboxing with directory isolation works correctly with `env/settings` values.
+    '''
+    # Mock away the things that would actually prepare the isolation directory.
+    mocker.patch('os.makedirs', return_value=True)
+    copy_tree = mocker.patch('shutil.copytree')
+    mkdtemp = mocker.patch('tempfile.mkdtemp')
+    mkdtemp.return_value = '/tmp/runner/runner_di_XYZ'
+    mocker.patch('ansible_runner.config.runner.RunnerConfig.build_process_isolation_temp_dir')
+
+    # The `directory_isolation` test data sets up an `env/settings` file for us.
+    private_data_dir = project_fixtures / 'directory_isolation'
+    rc = RunnerConfig(private_data_dir=str(private_data_dir), playbook='main.yaml')
+
+    # This is where all the magic happens
+    rc.prepare()
+
+    assert rc.sandboxed
+    assert rc.process_isolation_executable == 'bwrap'
+    assert rc.project_dir == str(private_data_dir / 'project')
+    assert os.path.exists(rc.project_dir)
+
+    # `directory_isolation_path` should be used to create a new temp path underneath
+    assert rc.directory_isolation_path == '/tmp/runner/runner_di_XYZ'
+    mkdtemp.assert_called_once_with(prefix='runner_di_', dir='/tmp/runner')
+
+    # The project files should be copied to the isolation path.
+    copy_tree.assert_called_once_with(rc.project_dir, rc.directory_isolation_path, symlinks=True)
+
+
 def test_prepare_inventory(mocker):
     mocker.patch('os.makedirs', return_value=True)
     path_exists = mocker.patch('os.path.exists', return_value=True)
@@ -405,7 +438,6 @@ def test_prepare_with_defaults(mocker):
 
 def test_prepare(mocker):
     mocker.patch.dict('os.environ', {
-        'PYTHONPATH': '/python_path_via_environ',
         'AWX_LIB_DIRECTORY': '/awx_lib_directory_via_environ',
     })
     mocker.patch('os.makedirs', return_value=True)
@@ -431,14 +463,6 @@ def test_prepare(mocker):
     assert rc.env['ANSIBLE_RETRY_FILES_ENABLED'] == 'False'
     assert rc.env['ANSIBLE_HOST_KEY_CHECKING'] == 'False'
     assert rc.env['AWX_ISOLATED_DATA_DIR'] == '/'
-    assert rc.env['PYTHONPATH'] == '/python_path_via_environ:/awx_lib_directory_via_environ', \
-        "PYTHONPATH is the union of the env PYTHONPATH and AWX_LIB_DIRECTORY"
-
-    del rc.env['PYTHONPATH']
-    os.environ['PYTHONPATH'] = "/foo/bar/python_path_via_environ"
-    rc.prepare()
-    assert rc.env['PYTHONPATH'] == "/foo/bar/python_path_via_environ:/awx_lib_directory_via_environ", \
-        "PYTHONPATH is the union of the explicit env['PYTHONPATH'] override and AWX_LIB_DIRECTORY"
 
 
 def test_prepare_with_ssh_key(mocker):
@@ -456,7 +480,8 @@ def test_prepare_with_ssh_key(mocker):
     rc.env = {}
     rc.execution_mode = ExecutionMode.ANSIBLE_PLAYBOOK
     rc.playbook = 'main.yaml'
-    rc.ssh_key_data = '01234567890'
+    rsa_key = RSAKey()
+    rc.ssh_key_data = rsa_key.private
     rc.command = 'ansible-playbook'
 
     mocker.patch.dict('os.environ', {'AWX_LIB_DIRECTORY': '/'})
@@ -540,8 +565,14 @@ def test_bwrap_process_isolation_defaults(mocker):
         'bwrap',
         '--die-with-parent',
         '--unshare-pid',
-        '--dev-bind', '/', '/',
+        '--dev-bind', '/dev', 'dev',
         '--proc', '/proc',
+        '--dir', '/tmp',
+        '--ro-bind', '/bin', '/bin',
+        '--ro-bind', '/etc', '/etc',
+        '--ro-bind', '/usr', '/usr',
+        '--ro-bind', '/opt', '/opt',
+        '--symlink', 'usr/lib64', '/lib64',
         '--bind', '/', '/',
         '--chdir', '/project',
         'ansible-playbook', '-i', '/inventory', 'main.yaml',
@@ -587,8 +618,14 @@ def test_bwrap_process_isolation_and_directory_isolation(mocker, patch_private_d
         'bwrap',
         '--die-with-parent',
         '--unshare-pid',
-        '--dev-bind', '/', '/',
+        '--dev-bind', '/dev', 'dev',
         '--proc', '/proc',
+        '--dir', '/tmp',
+        '--ro-bind', '/bin', '/bin',
+        '--ro-bind', '/etc', '/etc',
+        '--ro-bind', '/usr', '/usr',
+        '--ro-bind', '/opt', '/opt',
+        '--symlink', 'usr/lib64', '/lib64',
         '--bind', '/', '/',
         '--chdir', os.path.realpath(rc.directory_isolation_path),
         'ansible-playbook', '-i', '/inventory', 'main.yaml',
@@ -615,85 +652,43 @@ def test_process_isolation_settings(mocker, tmp_path):
 
     rc.prepare()
     print(rc.command)
-    assert rc.command[0:8] == [
+    expected = [
         'not_bwrap',
         '--die-with-parent',
         '--unshare-pid',
-        '--dev-bind', '/', '/',
+        '--dev-bind', '/dev', 'dev',
         '--proc', '/proc',
+        '--dir', '/tmp',
+        '--ro-bind', '/bin', '/bin',
+        '--ro-bind', '/etc', '/etc',
+        '--ro-bind', '/usr', '/usr',
+        '--ro-bind', '/opt', '/opt',
+        '--symlink', 'usr/lib64', '/lib64',
     ]
+    index = len(expected)
+    assert rc.command[0:index] == expected
 
     # hide /home
-    assert rc.command[8] == '--bind'
-    assert 'ansible_runner_pi' in rc.command[9]
-    assert rc.command[10] == os.path.realpath('/home')  # needed for Mac
+    assert rc.command[index] == '--bind'
+    assert 'ansible_runner_pi' in rc.command[index + 1]
+    assert rc.command[index + 2] == os.path.realpath('/home')  # needed for Mac
 
     # hide /var
-    assert rc.command[11] == '--bind'
-    assert 'ansible_runner_pi' in rc.command[12]
-    assert rc.command[13] == '/var' or rc.command[13] == '/private/var'
+    assert rc.command[index + 3] == '--bind'
+    assert 'ansible_runner_pi' in rc.command[index + 4]
+    assert rc.command[index + 5] in ('/var', '/private/var')
 
     # read-only bind
-    assert rc.command[14:17] == ['--ro-bind', '/venv', '/venv']
+    assert rc.command[index + 6:index + 9] == ['--ro-bind', '/venv', '/venv']
 
     # root bind
-    assert rc.command[17:20] == ['--bind', '/', '/']
+    assert rc.command[index + 9:index + 12] == ['--bind', '/', '/']
 
     # show /usr
-    assert rc.command[20:23] == ['--bind', '/usr', '/usr']
+    assert rc.command[index + 12:index + 15] == ['--bind', '/usr', '/usr']
 
     # chdir and ansible-playbook command
-    assert rc.command[23:] == ['--chdir', '/project', 'ansible-playbook', '-i', '/inventory', 'main.yaml']
-
-
-def test_profiling_plugin_settings(mocker):
-    mocker.patch('os.mkdir', return_value=True)
-
-    rc = RunnerConfig('/')
-    rc.playbook = 'main.yaml'
-    rc.command = 'ansible-playbook'
-    rc.resource_profiling = True
-    rc.resource_profiling_base_cgroup = 'ansible-runner'
-    rc.prepare()
-
-    expected_command_start = [
-        'cgexec',
-        '--sticky',
-        '-g',
-        'cpuacct,memory,pids:ansible-runner/{}'.format(rc.ident),
-        'ansible-playbook',
-        'main.yaml',
-    ]
-
-    assert expected_command_start == rc.command
-    assert 'main.yaml' in rc.command
-    assert rc.env['ANSIBLE_CALLBACK_WHITELIST'] == 'cgroup_perf_recap'
-    assert rc.env['CGROUP_CONTROL_GROUP'] == 'ansible-runner/{}'.format(rc.ident)
-    assert rc.env['CGROUP_OUTPUT_DIR'] == os.path.normpath(os.path.join(rc.private_data_dir, 'profiling_data'))
-    assert rc.env['CGROUP_OUTPUT_FORMAT'] == 'json'
-    assert rc.env['CGROUP_CPU_POLL_INTERVAL'] == '0.25'
-    assert rc.env['CGROUP_MEMORY_POLL_INTERVAL'] == '0.25'
-    assert rc.env['CGROUP_PID_POLL_INTERVAL'] == '0.25'
-    assert rc.env['CGROUP_FILE_PER_TASK'] == 'True'
-    assert rc.env['CGROUP_WRITE_FILES'] == 'True'
-    assert rc.env['CGROUP_DISPLAY_RECAP'] == 'False'
-
-
-def test_profiling_plugin_settings_with_custom_intervals(mocker):
-    mocker.patch('os.mkdir', return_value=True)
-
-    rc = RunnerConfig('/')
-    rc.playbook = 'main.yaml'
-    rc.command = 'ansible-playbook'
-    rc.resource_profiling = True
-    rc.resource_profiling_base_cgroup = 'ansible-runner'
-    rc.resource_profiling_cpu_poll_interval = '.5'
-    rc.resource_profiling_memory_poll_interval = '.75'
-    rc.resource_profiling_pid_poll_interval = '1.5'
-    rc.prepare()
-    assert rc.env['CGROUP_CPU_POLL_INTERVAL'] == '.5'
-    assert rc.env['CGROUP_MEMORY_POLL_INTERVAL'] == '.75'
-    assert rc.env['CGROUP_PID_POLL_INTERVAL'] == '1.5'
+    assert rc.command[index + 15:] == ['--chdir', '/project', 'ansible-playbook', '-i', '/inventory', 'main.yaml']
 
 
 def test_container_volume_mounting_with_Z(mocker, tmp_path):
@@ -715,13 +710,18 @@ def test_container_volume_mounting_with_Z(mocker, tmp_path):
         raise Exception('Could not find expected mount, args: {}'.format(new_args))
 
 
-@pytest.mark.test_all_runtimes
+@pytest.mark.parametrize('runtime', ('docker', 'podman'))
 def test_containerization_settings(tmp_path, runtime, mocker):
     mocker.patch('os.path.isdir', return_value=True)
     mocker.patch('os.path.exists', return_value=True)
     mock_containerized = mocker.patch('ansible_runner.runner_config.RunnerConfig.containerized', new_callable=mocker.PropertyMock)
     mock_containerized.return_value = True
 
+    # In this test get_callback_dir() will not return a callback plugin dir that exists
+    # mock shutil.copytree and shutil.rmtree to just return True instead of trying to copy
+    mocker.patch('shutil.copytree', return_value=True)
+    mocker.patch('shutil.rmtree', return_value=True)
+
     rc = RunnerConfig(tmp_path)
     rc.ident = 'foo'
     rc.playbook = 'main.yaml'
@@ -732,6 +732,14 @@ def test_containerization_settings(tmp_path, runtime, mocker):
     rc.container_volume_mounts = ['/host1:/container1', '/host2:/container2']
     rc.prepare()
 
+    # validate ANSIBLE_CALLBACK_PLUGINS env var is set
+    assert rc.env.get('ANSIBLE_CALLBACK_PLUGINS', None) is not None
+
+    # validate ANSIBLE_CALLBACK_PLUGINS contains callback plugin dir
+    callback_plugins = rc.env['ANSIBLE_CALLBACK_PLUGINS'].split(':')
+    callback_dir = os.path.join("/runner/artifacts", "{}".format(rc.ident), "callback")
+    assert callback_dir in callback_plugins
+
     extra_container_args = []
     if runtime == 'podman':
         extra_container_args = ['--quiet']
